@@ -3,6 +3,13 @@ import functools
 from .dataset import data_message_reader, Observation
 
 
+class MessageElementTypes(object):
+    def _expand(name):
+        return "{http://www.SDMX.org/resources/SDMXML/schemas/v2_0/message}" + name
+    
+    DataSet = _expand("DataSet")
+
+
 class GenericElementTypes(object):
     def _expand(name):
         return "{http://www.SDMX.org/resources/SDMXML/schemas/v2_0/generic}" + name
@@ -21,7 +28,10 @@ class GenericElementTypes(object):
 
 class GenericDataMessageParser(object):
     def get_dataset_elements(self, message_element):
-        return message_element.findall(GenericElementTypes.DataSet)
+        return (
+            message_element.findall(GenericElementTypes.DataSet) +
+            message_element.findall(MessageElementTypes.DataSet)
+        )
         
     def key_family_for_dataset(self, dataset_element, dsd_reader):
         key_family_ref_element = dataset_element.find(GenericElementTypes.KeyFamilyRef)
