@@ -12,13 +12,19 @@ __all__ = ["parse_xml", "inner_text", "XmlNode"]
 
 class XmlNode(object):
     def __init__(self, node):
+        if node is None:
+            raise ValueError("node is None")
         self._node = node
         
     def map_nodes(self, path, func):
         return map(func, self.findall(path))
     
     def find(self, path):
-        return XmlNode(self._node.find(path))
+        child = self._node.find(path)
+        if child is None:
+            return None
+        else:
+            return XmlNode(child)
     
     def findall(self, path):
         return map(XmlNode, self._node.findall(path))
@@ -35,7 +41,10 @@ class XmlNode(object):
             
     def local_name(self):
         return re.sub(r"\{[^}]*\}", "", self._node.tag)
-        
+    
+    def qualified_name(self):
+        return self._node.tag
+    
     def attributes(self):
         return self._node.items()
 
